const path = require('path');
const resolve = (url) => path.resolve(__dirname, "..", url);

module.exports = {
    entry: {
        'worker-transfer-data': resolve("src/index.ts"),
    },
    module: {
        rules: [
            {
                test: /\.tsx?$/,
                use: [
                    {
                        loader: 'ts-loader'
                    }
                ]
            },
            {
                test: /\.xml$/,
                use: {
                    loader: 'raw-loader',
                },
                type: "javascript/auto"
            },
            {
                test: /\.(png|svg|jpe?g|gif)$/i,
                use: [
                    {
                        loader: 'url-loader',
                        options: {
                            limit: 18192,
                            outputPath: 'img',
                            name: '[name].[ext]?[hash]',
                            esModule: false,
                        },
                    },
                ],
                type:"javascript/auto"
            },
            {
                test: /\.(mp3|wav)$/i,
                use: [
                    {
                        loader: 'file-loader',
                        options: {
                            outputPath: 'audio',
                            esModule: false,
                        },
                    },
                ],
                type:"javascript/auto"
            },
            {
                test: /\.(woff|woff2|eot|ttf|otf)$/i,
                use: [
                    {
                        loader: 'file-loader',
                        options: {
                            outputPath: 'font',
                            esModule: false,
                        },
                    },
                ],
                type:"javascript/auto"
            },
            {
                test: /\.wasm$/,
                type: 'webassembly/async',
            },
        ],
    },
    resolve: {
        extensions: ['.ts', '.tsx', '.js', '.json'],
        alias: {
            '@': resolve('src'),
        },
    },
    experiments: {
        syncWebAssembly: true,
        asyncWebAssembly: true,
        topLevelAwait: true,
    }
};
